Learn R Programming

mistral (version 1.1-1)

mistral-package: Methods in structural reliability

Description

Provide tools for structural reliability analysis (failure probability, quantile).

Arguments

Details

lll{ Package: mistral Type: Package Version: 1.1-0 Date: 2013-12-17 License: CeCILL } This package provides tools for structural reliability analysis:
  • Calculate failure probability with FORM method and importance sampling, compute the design point, give the importance factors.
  • Calculate failure probability with crude Monte Carlo method
  • Calculate failure probability with Subset Simulation algorithm
  • Calculate failure probability with Monotonic Reliability Methods (MRM)
  • Calculate failure probability with metamodel based algorithms : AKMCS, SMART and MetaIS
  • Calculate failure probability with a metamodel based Subset Simulation : S2MART
  • Compute Wilks formula (minimal size of a sample to estimate quantile with a confidence level).

References

S.-K. Au, J. L. Beck. Estimation of small failure probabilities in high dimensions by Subset Simulation. Probabilistic Engineering Mechanics, 2001. J.-M. Bourinet, F. Deheeger, M. Lemaire. Assessing small failure probabilities by combined Subset Simulation and Support Vector Machines. Structural Safety, 2011. N. Bousquet. Accelerated monte carlo estimation of exceedance probabilities under monotonicity constraints. Annales de la Faculte des Sciences de Toulouse. XXI(3), 557-592, 2012 H.A. David and H.N. Nagaraja. Order statistics, Wiley, 2003. F. Deheeger. Couplage mecano-fiabiliste : 2SMART - methodologie d'apprentissage stochastique en fiabilite. PhD. Thesis, Universite Blaise Pascal - Clermont II, 2008 A. Der Kiureghian, T. Dakessian. Multiple design points in first and second-order reliability. Structural Safety, vol.20, 1998. O. Ditlevsen and H.O. Madsen. Structural reliability methods, Wiley, 1996. V. Dubourg. Meta-modeles adaptatifs pour l'analyse de fiabilite et l'optimisation sous containte fiabiliste. PhD. Thesis, Universite Blaise Pascal - Clermont II, 2011. B. Echard, N. Gayton, M. Lemaire. AK-MCS : an Active learning reliability method combining Kriging and Monte Carlo Simulation M. Lemaire, A. Chateauneuf and J. Mitteau. Structural reliability, Wiley Online Library, 2009. W.T. Nutt and G.B. Wallis. Evaluation of nuclear safety from the outputs of computer codes in the presence of uncertainties. Reliability Engineering and System Safety, 83:57-77, 2004. P.-H. Waarts. Structural reliability using finite element methods: an appraisal of DARS, Directional Adaptive Response Surface Sampling. PhD. Thesis, Technical University of Delft, The Netherlands, 2000. S.S. Wilks. Determination of Sample Sizes for Setting Tolerance Limits. Annals Mathematical Statistics, 12:91-96, 1941.

Examples

Run this code
########## FORM ###########

 distribution = list()
 distribution[[1]] = list("gamma",c(2,1))
 distribution[[2]] = list("gamma",c(3,1))

 func <- function(X){
   X[1]/sum(X) - qbeta((1e-5),2,3)
 }

 res.list <- FORM(func, u.dep = c(0,0.1), choice.law = distribution, 
     N.calls = 1000, eps = 1e-7, Method = "HLRF", IS = "TRUE", 
     q = 0.1, copula = "unif")

########### Wilks ##########

N <- WilksFormula(0.95,0.95,order=1)
print(N)

Run the code above in your browser using DataLab